@@ -6,6 +6,10 @@ files <- list.files("vignettes")
 orig_ind <- grep("orig", files)
 orig_files <- files[orig_ind]
 
+# In case you want to compile only one of the vignettes:
+orig_files
+#orig_files <- orig_files[2]
+
 # Knit all vignettes
 for(vignette_file in orig_files){
   vignette_name <- paste0("vignettes/", vignette_file)
